/**
  ******************************************************************************
  * @file    fm33a0xx_pmu.h
  * @author  FM33a0xx Application Team
  * @version V3.00
  * @date    
  * @brief   This file contains all the functions prototypes for the PMU firmware library.  
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __FM33A0xx_PMU_H
#define __FM33A0xx_PMU_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "FM33A0XX.h"
	 
/** @addtogroup FM33a0xx_StdPeriph_Driver
  * @{
  */

/** @addtogroup PMU
  * @{
  */

	 
/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  PMU Init Structure definition  
  */   
  
typedef struct
{
	uint32_t PMOD;				/*!<͹ģʽ  */	
	uint32_t SLPDP;				/*!<DeepSleepƼĴ  */
	uint32_t DSLPRAM_EXT;		/*!<DeepSleepģʽRAMݱ  */	
	FunState CVS;				/*!<ں˵ѹʹܿ  */
	uint32_t XTOFF;				/*!<رXTLFSLEEP/DEEPSLEEP  */
	uint32_t SCR;				/*!<M0ϵͳƼĴһΪ0  */	
}PMU_SleepCfg_InitTypeDef;


/* Exported constants --------------------------------------------------------*/
/* Exported macro ------------------------------------------------------------*/

//Macro_START
//2018-04-02-13-22-03
//FM33A0XX_Driver_Gen_V1.4

#define	PMU_LPMCFG_XTOFF_Pos	18	/* رXTLF */
#define	PMU_LPMCFG_XTOFF_Msk	(0x3U << PMU_LPMCFG_XTOFF_Pos)
#define	PMU_LPMCFG_XTOFF_DIS	(0x1U << PMU_LPMCFG_XTOFF_Pos)	/* 01: XTLF */
#define	PMU_LPMCFG_XTOFF_EN	(0x2U << PMU_LPMCFG_XTOFF_Pos)	/* 10: رXTLF */

#define	PMU_LPMCFG_LDO15EN_Pos	17	/* LDO15ʹ״ֻ̬ */
#define	PMU_LPMCFG_LDO15EN_Msk	(0x1U << PMU_LPMCFG_LDO15EN_Pos)

#define	PMU_LPMCFG_DSLPRAM_EXT_Pos	10	/* DeepSleepģʽRAMݱλ */
#define	PMU_LPMCFG_DSLPRAM_EXT_Msk	(0x1U << PMU_LPMCFG_DSLPRAM_EXT_Pos)
#define	PMU_LPMCFG_DSLPRAM_EXT_ALLRAMON	(0x0U << PMU_LPMCFG_DSLPRAM_EXT_Pos)	/* 0DeepSleep±RAM */
#define	PMU_LPMCFG_DSLPRAM_EXT_16KRAMON	(0x1U << PMU_LPMCFG_DSLPRAM_EXT_Pos)	/* 1DeepSleep½16KB RAM */

#define	PMU_LPMCFG_SLPDP_Pos	9	/* DeepSleepƼ */
#define	PMU_LPMCFG_SLPDP_Msk	(0x1U << PMU_LPMCFG_SLPDP_Pos)
#define	PMU_LPMCFG_SLPDP_SLEEP	(0x0U << PMU_LPMCFG_SLPDP_Pos)	/* 0Sleepģʽ */
#define	PMU_LPMCFG_SLPDP_DEEPSLEEP	(0x1U << PMU_LPMCFG_SLPDP_Pos)	/* 1DeepSleepģʽ */

#define	PMU_LPMCFG_CVS_Pos	8	/* ͹ģʽں˵ѹ */
#define	PMU_LPMCFG_CVS_Msk	(0x1U << PMU_LPMCFG_CVS_Pos)
	/* 0͹ģʽ²ʹں˵ѹ */
	/* 1͹ģʽ½ں˵ѹ */

#define	PMU_LPMCFG_PMOD_Pos	0	/* ͹ģʽüĴ */
#define	PMU_LPMCFG_PMOD_Msk	(0x3U << PMU_LPMCFG_PMOD_Pos)
#define	PMU_LPMCFG_PMOD_ACTIVE	(0x0U << PMU_LPMCFG_PMOD_Pos)	/* 00: Active mode */
#define	PMU_LPMCFG_PMOD_LPRUN	(0x1U << PMU_LPMCFG_PMOD_Pos)	/* 01: LPRUN mode */
#define	PMU_LPMCFG_PMOD_SLEEP	(0x2U << PMU_LPMCFG_PMOD_Pos)	/* 10: Sleep mode */

#define	PMU_WKDLYCON_TRHR_Pos	0	/* ʱƼĴ */
#define	PMU_WKDLYCON_TRHR_Msk	(0x3U << PMU_WKDLYCON_TRHR_Pos)
#define	PMU_WKDLYCON_TRHR_12US	(0x0U << PMU_WKDLYCON_TRHR_Pos)	/* 0012us */
#define	PMU_WKDLYCON_TRHR_16US	(0x1U << PMU_WKDLYCON_TRHR_Pos)	/* 0116us */
#define	PMU_WKDLYCON_TRHR_24US	(0x2U << PMU_WKDLYCON_TRHR_Pos)	/* 1024us */
#define	PMU_WKDLYCON_TRHR_32US	(0x3U << PMU_WKDLYCON_TRHR_Pos)	/* 1132us */

#define	PMU_WKPFLAG_DBGWKF_Pos	8	/* CPU Debuggerѱ־ */
#define	PMU_WKPFLAG_DBGWKF_Msk	(0x1U << PMU_WKPFLAG_DBGWKF_Pos)

#define	PMU_WKPFLAG_WKP7F_Pos	7	/* NWKUP7 Pinѱ־ */
#define	PMU_WKPFLAG_WKP7F_Msk	(0x1U << PMU_WKPFLAG_WKP7F_Pos)

#define	PMU_WKPFLAG_WKP6F_Pos	6	/* NWKUP6 Pinѱ־ */
#define	PMU_WKPFLAG_WKP6F_Msk	(0x1U << PMU_WKPFLAG_WKP6F_Pos)

#define	PMU_WKPFLAG_WKP5F_Pos	5	/* NWKUP5 Pinѱ־ */
#define	PMU_WKPFLAG_WKP5F_Msk	(0x1U << PMU_WKPFLAG_WKP5F_Pos)

#define	PMU_WKPFLAG_WKP4F_Pos	4	/* NWKUP4 Pinѱ־ */
#define	PMU_WKPFLAG_WKP4F_Msk	(0x1U << PMU_WKPFLAG_WKP4F_Pos)

#define	PMU_WKPFLAG_WKP3F_Pos	3	/* NWKUP3 Pinѱ־ */
#define	PMU_WKPFLAG_WKP3F_Msk	(0x1U << PMU_WKPFLAG_WKP3F_Pos)

#define	PMU_WKPFLAG_WKP2F_Pos	2	/* NWKUP2 Pinѱ־ */
#define	PMU_WKPFLAG_WKP2F_Msk	(0x1U << PMU_WKPFLAG_WKP2F_Pos)

#define	PMU_WKPFLAG_WKP1F_Pos	1	/* NWKUP1 Pinѱ־ */
#define	PMU_WKPFLAG_WKP1F_Msk	(0x1U << PMU_WKPFLAG_WKP1F_Pos)

#define	PMU_WKPFLAG_WKP0F_Pos	0	/* NWKUP0 Pinѱ־ */
#define	PMU_WKPFLAG_WKP0F_Msk	(0x1U << PMU_WKPFLAG_WKP0F_Pos)

#define	PMU_LPREIE_SLPEIE_Pos	1	/* SLEEPжʹ */
#define	PMU_LPREIE_SLPEIE_Msk	(0x1U << PMU_LPREIE_SLPEIE_Pos)
	/* 0ֹSLEEPж */
	/* 1ʹSLEEPж */

#define	PMU_LPREIE_LPREIE_Pos	0	/* LPRUNжʹ */
#define	PMU_LPREIE_LPREIE_Msk	(0x1U << PMU_LPREIE_LPREIE_Pos)
	/* 0ֹLPRUNж */
	/* 1ʹLPRUNж */

#define	PMU_LPREIF_SLPEIF_Pos	1	/* SLEEPжϱ־Ӳλд1,PMOD=2h2CPUִWFI/WFEָǰλSLEEPDEEPĴʱλ */
#define	PMU_LPREIF_SLPEIF_Msk	(0x1U << PMU_LPREIF_SLPEIF_Pos)

#define	PMU_LPREIF_LPREIF_Pos	0	/* LPRUNжϱ־Ӳλд1㣻LPRUNģʽʱLPREIFоƬԽͣACTIVEģʽ,LPRUN Condition ErrorLPRUNʱ
1 HSCLKѡLSCLKRCLP
2 RCHFPLLADCʹδر
 */
#define	PMU_LPREIF_LPREIF_Msk	(0x1U << PMU_LPREIF_LPREIF_Pos)
//Macro_End

/* Exported functions --------------------------------------------------------*/ 
extern void PMU_Deinit(void);

/* رXTLF غ */
extern void PMU_LPMCFG_XTOFF_Set(uint32_t SetValue);
extern uint32_t PMU_LPMCFG_XTOFF_Get(void);

/* LDO15ʹ״ֻ̬ غ */
extern FlagStatus PMU_LPMCFG_LDO15EN_Chk(void);

/* DeepSleepģʽRAMݱλ غ */
extern void PMU_LPMCFG_DSLPRAM_EXT_Set(uint32_t SetValue);
extern uint32_t PMU_LPMCFG_DSLPRAM_EXT_Get(void);

/* DeepSleepƼ غ */
extern void PMU_LPMCFG_SLPDP_Set(uint32_t SetValue);
extern uint32_t PMU_LPMCFG_SLPDP_Get(void);

/* ͹ģʽں˵ѹ غ */
extern void PMU_LPMCFG_CVS_Setable(FunState NewState);
extern FunState PMU_LPMCFG_CVS_Getable(void);

/* ͹ģʽüĴ غ */
extern void PMU_LPMCFG_PMOD_Set(uint32_t SetValue);
extern uint32_t PMU_LPMCFG_PMOD_Get(void);

/* ʱƼĴ غ */
extern void PMU_WKDLYCON_TRHR_Set(uint32_t SetValue);
extern uint32_t PMU_WKDLYCON_TRHR_Get(void);

/* CPU Debuggerѱ־ غ */
extern void PMU_WKPFLAG_DBGWKF_Clr(void);
extern FlagStatus PMU_WKPFLAG_DBGWKF_Chk(void);

/* SLEEPжʹ غ */
extern void PMU_LPREIE_SLPEIE_Setable(FunState NewState);
extern FunState PMU_LPREIE_SLPEIE_Getable(void);

/* LPRUNжʹ غ */
extern void PMU_LPREIE_LPREIE_Setable(FunState NewState);
extern FunState PMU_LPREIE_LPREIE_Getable(void);

/* SLEEPжϱ־Ӳλд1,PMOD=2h2CPUִWFI/WFEָǰλSLEEPDEEPĴʱλ غ */
extern void PMU_LPREIF_SLPEIF_Clr(void);
extern FlagStatus PMU_LPREIF_SLPEIF_Chk(void);

/* LPRUNжϱ־Ӳλд1㣻LPRUNģʽʱLPREIFоƬԽͣACTIVEģʽ,LPRUN Condition ErrorLPRUNʱ
1 HSCLKѡLSCLKRCLP
2 RCHFPLLADCʹδر
 غ */
extern void PMU_LPREIF_LPREIF_Clr(void);
extern FlagStatus PMU_LPREIF_LPREIF_Chk(void);
//Announce_End


extern void PMU_WKPFLAG_WKPxF_ClrEx(uint32_t NWKPinDef);
extern FlagStatus PMU_WKPFLAG_WKPxF_ChkEx(uint32_t NWKPinDef);
extern void PMU_SleepCfg_Init(PMU_SleepCfg_InitTypeDef* SleepCfg_InitStruct);




#ifdef __cplusplus
}
#endif

#endif /* __FM33A0xx_PMU_H */



/************************ (C) COPYRIGHT FMSHelectronics *****END OF FILE****/



